@@ -26,6 +26,11 @@
 #' provide additional parameters to the program \command{pngquant}, e.g.
 #' \code{pngquant = '--speed=1 --quality=0-50'}.
 #'
+#' The function \code{hook_mogrify()} calls the program \command{mogrify}.  Note
+#' the chunk option \code{mogrify} can be used to provide additional parameters
+#' to the program \command{mogrify} (with default \code{-trim} to trim PNG
+#' files).
+#'
 #' When the plots are not recordable via \code{\link[grDevices]{recordPlot}} and
 #' we save the plots to files manually via other functions (e.g. \pkg{rgl}
 #' plots), we can use the chunk hook \code{hook_plot_custom} to help write code
@@ -43,11 +48,11 @@
 #' turned on (the chunk option \code{cache = TRUE}), no chunk hooks will be
 #' executed, hence \code{hook_purl()} will not work, either. To solve this
 #' problem, we need \code{cache = 2} instead of \code{TRUE} (see
-#' \url{https://yihui.name/knitr/demo/cache/} for the meaning of \code{cache =
+#' \url{https://yihui.org/knitr/demo/cache/} for the meaning of \code{cache =
 #' 2}).
 #' @rdname chunk_hook
-#' @param before,options,envir see references
-#' @references \url{https://yihui.name/knitr/hooks/#chunk_hooks}
+#' @param before,options,envir See \emph{References} below.
+#' @references \url{https://yihui.org/knitr/hooks/#chunk_hooks}
 #' @seealso \code{\link[rgl]{rgl.snapshot}}, \code{\link[rgl]{rgl.postscript}},
 #'   \code{\link[rgl]{hook_rgl}}, \code{\link[rgl]{hook_webgl}}
 #' @note The two hook functions \code{hook_rgl()} and \code{hook_webgl()} were
@@ -71,9 +76,11 @@ hook_optipng = function(before, options, envir) {
 }
 
 hook_png = function(
-  before, options, envir, cmd = c('optipng', 'pngquant'), post_process = identity
+  before, options, envir, cmd = c('optipng', 'pngquant', 'mogrify'), post_process = identity
 ) {
   if (before) return()
+  num = options$fig.num
+  if (length(num) == 0 || num == 0) return()  # no figures
   ext = tolower(options$fig.ext)
   if (ext != 'png') {
     warning('this hook only works with PNG at the moment'); return()
@@ -107,6 +114,13 @@ hook_pngquant = function(before, options, envir) {
   })
 }
 
+#' @export
+#' @rdname chunk_hook
+hook_mogrify = function(before, options, envir) {
+  if (is.null(options[['mogrify']])) options$mogrify = '-trim'
+  hook_png(before, options, envir, cmd = 'mogrify', identity)
+}
+
 #' @export
 #' @rdname chunk_hook
 hook_plot_custom = function(before, options, envir){
@@ -138,13 +152,17 @@ hook_purl = function(before, options, envir) {
     unlink(output)
     # write out knit_params() data from YAML
     params = .knitEnv$tangle.params
-    if (length(params)) writeLines(params, output)
+    if (length(params)) write_utf8(params, output)
     .knitEnv$tangle.params = NULL
   }
 
   code = options$code
   if (isFALSE(options$eval)) code = comment_out(code, '# ', newline = FALSE)
   if (is.character(output)) {
-    cat(label_code(code, options$params.src), file = output, sep = '\n', append = TRUE)
+    code = c(
+      if (file.exists(output)) read_utf8(output),
+      label_code(code, options$params.src)
+    )
+    write_utf8(code, output)
   }
 }
