@@ -107,9 +107,9 @@
 #'   the R script generated by \code{purl()}. This seems to be obvious, but some
 #'   people \href{http://bit.ly/SnLi6h}{just do not get it}.
 #' @export
-#' @references Package homepage: \url{https://yihui.name/knitr/}. The \pkg{knitr}
-#'   \href{https://yihui.name/knitr/demo/manual/}{main manual}: and
-#'   \href{https://yihui.name/knitr/demo/graphics/}{graphics manual}.
+#' @references Package homepage: \url{https://yihui.org/knitr/}. The \pkg{knitr}
+#'   \href{https://yihui.org/knitr/demo/manual/}{main manual}: and
+#'   \href{https://yihui.org/knitr/demo/graphics/}{graphics manual}.
 #'
 #'   See \code{citation('knitr')} for the citation information.
 #' @examples library(knitr)
@@ -190,7 +190,7 @@ knit = function(
     text = readLines(input, encoding = 'UTF-8', warn = FALSE)
     if (!is_utf8(text)) warning(
       'The file "', input, '" must be encoded in UTF-8. Please see ',
-      'https://yihui.name/en/2018/11/biggest-regret-knitr/ for more info.'
+      'https://yihui.org/en/2018/11/biggest-regret-knitr/ for more info.'
     )
   } else text = split_lines(text) # make sure each element is one line
   if (!length(text)) {
@@ -370,7 +370,7 @@ auto_format = function(ext) {
 #' @return A character string of the content of the compiled child document is
 #'   returned as a character string so it can be written back to the parent
 #'   document directly.
-#' @references \url{https://yihui.name/knitr/demo/child/}
+#' @references \url{https://yihui.org/knitr/demo/child/}
 #' @note This function is not supposed be called directly like
 #'   \code{\link{knit}()}; instead it must be placed in a parent document to let
 #'   \code{\link{knit}()} call it indirectly.
@@ -554,7 +554,6 @@ wrap.recordedplot = function(x, options) {
 wrap.knit_image_paths = function(x, options = opts_chunk$get(), inline = FALSE) {
   if (options$fig.show == 'hide') return('')
   hook_plot = knit_hooks$get('plot')
-  options$fig.num = length(x)
   # remove the automatically set out.width when fig.retina is set, otherwise the
   # size of external images embedded via include_graphics() will be set to
   # fig.width * dpi in fix_options()
